pub struct DefaultLifecycle;Trait Implementations
Sourceimpl Clone for DefaultLifecycle
impl Clone for DefaultLifecycle
Sourcefn clone(&self) -> DefaultLifecycle
fn clone(&self) -> DefaultLifecycle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DefaultLifecycle
impl Debug for DefaultLifecycle
Sourceimpl Default for DefaultLifecycle
impl Default for DefaultLifecycle
Sourcefn default() -> DefaultLifecycle
fn default() -> DefaultLifecycle
Returns the “default value” for a type. Read more
Sourceimpl<K, V> Lifecycle<K, V> for DefaultLifecycle
impl<K, V> Lifecycle<K, V> for DefaultLifecycle
Sourcefn on_eviction(&mut self, _key: K, _value: V)
fn on_eviction(&mut self, _key: K, _value: V)
Called when an entry has been evicted from the cache. Receives ownership
of the key and value so they can be forwarded or dropped.
Sourcefn evaluate(&self, _key: &K, _value: &V) -> EntryStatus
fn evaluate(&self, _key: &K, _value: &V) -> EntryStatus
Inspect an existing entry and decide whether it should remain in the
cache. Called as the sieve hand passes over entries during
Cache::put.impl Copy for DefaultLifecycle